# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harbor_client.api_client import ApiClient


class Robotv1Api(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_robot_v1(self, project_name_or_id, robot, **kwargs):  # noqa: E501
        """Create a robot account  # noqa: E501

        Create a robot account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_robot_v1(project_name_or_id, robot, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param RobotCreateV1 robot: The JSON object of a robot account. (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :return: RobotCreated
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_robot_v1_with_http_info(project_name_or_id, robot, **kwargs)  # noqa: E501
        else:
            (data) = self.create_robot_v1_with_http_info(project_name_or_id, robot, **kwargs)  # noqa: E501
            return data

    def create_robot_v1_with_http_info(self, project_name_or_id, robot, **kwargs):  # noqa: E501
        """Create a robot account  # noqa: E501

        Create a robot account  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_robot_v1_with_http_info(project_name_or_id, robot, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param RobotCreateV1 robot: The JSON object of a robot account. (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :return: RobotCreated
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_name_or_id', 'robot', 'x_request_id', 'x_is_resource_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_robot_v1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_name_or_id' is set
        if self.api_client.client_side_validation and ('project_name_or_id' not in params or
                                                       params['project_name_or_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_name_or_id` when calling `create_robot_v1`")  # noqa: E501
        # verify the required parameter 'robot' is set
        if self.api_client.client_side_validation and ('robot' not in params or
                                                       params['robot'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `robot` when calling `create_robot_v1`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `create_robot_v1`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'project_name_or_id' in params:
            path_params['project_name_or_id'] = params['project_name_or_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501
        if 'x_is_resource_name' in params:
            header_params['X-Is-Resource-Name'] = params['x_is_resource_name']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'robot' in params:
            body_params = params['robot']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_name_or_id}/robots', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RobotCreated',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_robot_v1(self, project_name_or_id, robot_id, **kwargs):  # noqa: E501
        """Delete a robot account  # noqa: E501

        This endpoint deletes specific robot account information by robot ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_robot_v1(project_name_or_id, robot_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param int robot_id: Robot ID (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_robot_v1_with_http_info(project_name_or_id, robot_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_robot_v1_with_http_info(project_name_or_id, robot_id, **kwargs)  # noqa: E501
            return data

    def delete_robot_v1_with_http_info(self, project_name_or_id, robot_id, **kwargs):  # noqa: E501
        """Delete a robot account  # noqa: E501

        This endpoint deletes specific robot account information by robot ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_robot_v1_with_http_info(project_name_or_id, robot_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param int robot_id: Robot ID (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_name_or_id', 'robot_id', 'x_request_id', 'x_is_resource_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_robot_v1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_name_or_id' is set
        if self.api_client.client_side_validation and ('project_name_or_id' not in params or
                                                       params['project_name_or_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_name_or_id` when calling `delete_robot_v1`")  # noqa: E501
        # verify the required parameter 'robot_id' is set
        if self.api_client.client_side_validation and ('robot_id' not in params or
                                                       params['robot_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `robot_id` when calling `delete_robot_v1`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `delete_robot_v1`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'project_name_or_id' in params:
            path_params['project_name_or_id'] = params['project_name_or_id']  # noqa: E501
        if 'robot_id' in params:
            path_params['robot_id'] = params['robot_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501
        if 'x_is_resource_name' in params:
            header_params['X-Is-Resource-Name'] = params['x_is_resource_name']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_name_or_id}/robots/{robot_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_robot_by_idv1(self, project_name_or_id, robot_id, **kwargs):  # noqa: E501
        """Get a robot account  # noqa: E501

        This endpoint returns specific robot account information by robot ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_robot_by_idv1(project_name_or_id, robot_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param int robot_id: Robot ID (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :return: Robot
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_robot_by_idv1_with_http_info(project_name_or_id, robot_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_robot_by_idv1_with_http_info(project_name_or_id, robot_id, **kwargs)  # noqa: E501
            return data

    def get_robot_by_idv1_with_http_info(self, project_name_or_id, robot_id, **kwargs):  # noqa: E501
        """Get a robot account  # noqa: E501

        This endpoint returns specific robot account information by robot ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_robot_by_idv1_with_http_info(project_name_or_id, robot_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param int robot_id: Robot ID (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :return: Robot
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_name_or_id', 'robot_id', 'x_request_id', 'x_is_resource_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_robot_by_idv1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_name_or_id' is set
        if self.api_client.client_side_validation and ('project_name_or_id' not in params or
                                                       params['project_name_or_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_name_or_id` when calling `get_robot_by_idv1`")  # noqa: E501
        # verify the required parameter 'robot_id' is set
        if self.api_client.client_side_validation and ('robot_id' not in params or
                                                       params['robot_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `robot_id` when calling `get_robot_by_idv1`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_robot_by_idv1`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'project_name_or_id' in params:
            path_params['project_name_or_id'] = params['project_name_or_id']  # noqa: E501
        if 'robot_id' in params:
            path_params['robot_id'] = params['robot_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501
        if 'x_is_resource_name' in params:
            header_params['X-Is-Resource-Name'] = params['x_is_resource_name']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_name_or_id}/robots/{robot_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Robot',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_robot_v1(self, project_name_or_id, **kwargs):  # noqa: E501
        """Get all robot accounts of specified project  # noqa: E501

        Get all robot accounts of specified project  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_robot_v1(project_name_or_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :param int page: The page number
        :param int page_size: The size of per page
        :param str q: Query string to query resources. Supported query patterns are \"exact match(k=v)\", \"fuzzy match(k=~v)\", \"range(k=[min~max])\", \"list with union releationship(k={v1 v2 v3})\" and \"list with intersetion relationship(k=(v1 v2 v3))\". The value of range and list can be string(enclosed by \" or '), integer or time(in format \"2020-04-09 02:36:00\"). All of these query patterns should be put in the query string \"q=xxx\" and splitted by \",\". e.g. q=k1=v1,k2=~v2,k3=[min~max]
        :param str sort: Sort the resource list in ascending or descending order. e.g. sort by field1 in ascending orderr and field2 in descending order with \"sort=field1,-field2\"
        :return: list[Robot]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_robot_v1_with_http_info(project_name_or_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_robot_v1_with_http_info(project_name_or_id, **kwargs)  # noqa: E501
            return data

    def list_robot_v1_with_http_info(self, project_name_or_id, **kwargs):  # noqa: E501
        """Get all robot accounts of specified project  # noqa: E501

        Get all robot accounts of specified project  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_robot_v1_with_http_info(project_name_or_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :param int page: The page number
        :param int page_size: The size of per page
        :param str q: Query string to query resources. Supported query patterns are \"exact match(k=v)\", \"fuzzy match(k=~v)\", \"range(k=[min~max])\", \"list with union releationship(k={v1 v2 v3})\" and \"list with intersetion relationship(k=(v1 v2 v3))\". The value of range and list can be string(enclosed by \" or '), integer or time(in format \"2020-04-09 02:36:00\"). All of these query patterns should be put in the query string \"q=xxx\" and splitted by \",\". e.g. q=k1=v1,k2=~v2,k3=[min~max]
        :param str sort: Sort the resource list in ascending or descending order. e.g. sort by field1 in ascending orderr and field2 in descending order with \"sort=field1,-field2\"
        :return: list[Robot]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_name_or_id', 'x_request_id', 'x_is_resource_name', 'page', 'page_size', 'q', 'sort']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_robot_v1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_name_or_id' is set
        if self.api_client.client_side_validation and ('project_name_or_id' not in params or
                                                       params['project_name_or_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_name_or_id` when calling `list_robot_v1`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `list_robot_v1`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('page_size' in params and params['page_size'] > 100):  # noqa: E501
            raise ValueError("Invalid value for parameter `page_size` when calling `list_robot_v1`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'project_name_or_id' in params:
            path_params['project_name_or_id'] = params['project_name_or_id']  # noqa: E501

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('page_size', params['page_size']))  # noqa: E501
        if 'q' in params:
            query_params.append(('q', params['q']))  # noqa: E501
        if 'sort' in params:
            query_params.append(('sort', params['sort']))  # noqa: E501

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501
        if 'x_is_resource_name' in params:
            header_params['X-Is-Resource-Name'] = params['x_is_resource_name']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_name_or_id}/robots', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Robot]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_robot_v1(self, project_name_or_id, robot_id, robot, **kwargs):  # noqa: E501
        """Update status of robot account.  # noqa: E501

        Used to disable/enable a specified robot account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_robot_v1(project_name_or_id, robot_id, robot, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param int robot_id: Robot ID (required)
        :param Robot robot: The JSON object of a robot account. (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_robot_v1_with_http_info(project_name_or_id, robot_id, robot, **kwargs)  # noqa: E501
        else:
            (data) = self.update_robot_v1_with_http_info(project_name_or_id, robot_id, robot, **kwargs)  # noqa: E501
            return data

    def update_robot_v1_with_http_info(self, project_name_or_id, robot_id, robot, **kwargs):  # noqa: E501
        """Update status of robot account.  # noqa: E501

        Used to disable/enable a specified robot account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_robot_v1_with_http_info(project_name_or_id, robot_id, robot, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_name_or_id: The name or id of the project (required)
        :param int robot_id: Robot ID (required)
        :param Robot robot: The JSON object of a robot account. (required)
        :param str x_request_id: An unique ID for the request
        :param bool x_is_resource_name: The flag to indicate whether the parameter which supports both name and id in the path is the name of the resource. When the X-Is-Resource-Name is false and the parameter can be converted to an integer, the parameter will be as an id, otherwise, it will be as a name.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_name_or_id', 'robot_id', 'robot', 'x_request_id', 'x_is_resource_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_robot_v1" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_name_or_id' is set
        if self.api_client.client_side_validation and ('project_name_or_id' not in params or
                                                       params['project_name_or_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_name_or_id` when calling `update_robot_v1`")  # noqa: E501
        # verify the required parameter 'robot_id' is set
        if self.api_client.client_side_validation and ('robot_id' not in params or
                                                       params['robot_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `robot_id` when calling `update_robot_v1`")  # noqa: E501
        # verify the required parameter 'robot' is set
        if self.api_client.client_side_validation and ('robot' not in params or
                                                       params['robot'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `robot` when calling `update_robot_v1`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `update_robot_v1`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'project_name_or_id' in params:
            path_params['project_name_or_id'] = params['project_name_or_id']  # noqa: E501
        if 'robot_id' in params:
            path_params['robot_id'] = params['robot_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501
        if 'x_is_resource_name' in params:
            header_params['X-Is-Resource-Name'] = params['x_is_resource_name']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'robot' in params:
            body_params = params['robot']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/projects/{project_name_or_id}/robots/{robot_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ScannerRegistration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'uuid': 'str',
        'name': 'str',
        'description': 'str',
        'url': 'str',
        'disabled': 'bool',
        'is_default': 'bool',
        'auth': 'str',
        'access_credential': 'str',
        'skip_cert_verify': 'bool',
        'use_internal_addr': 'bool',
        'create_time': 'datetime',
        'update_time': 'datetime',
        'adapter': 'str',
        'vendor': 'str',
        'version': 'str',
        'health': 'str'
    }

    attribute_map = {
        'uuid': 'uuid',
        'name': 'name',
        'description': 'description',
        'url': 'url',
        'disabled': 'disabled',
        'is_default': 'is_default',
        'auth': 'auth',
        'access_credential': 'access_credential',
        'skip_cert_verify': 'skip_certVerify',
        'use_internal_addr': 'use_internal_addr',
        'create_time': 'create_time',
        'update_time': 'update_time',
        'adapter': 'adapter',
        'vendor': 'vendor',
        'version': 'version',
        'health': 'health'
    }

    def __init__(self, uuid=None, name=None, description=None, url=None, disabled=False, is_default=False, auth='', access_credential=None, skip_cert_verify=False, use_internal_addr=False, create_time=None, update_time=None, adapter=None, vendor=None, version=None, health='', _configuration=None):  # noqa: E501
        """ScannerRegistration - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._uuid = None
        self._name = None
        self._description = None
        self._url = None
        self._disabled = None
        self._is_default = None
        self._auth = None
        self._access_credential = None
        self._skip_cert_verify = None
        self._use_internal_addr = None
        self._create_time = None
        self._update_time = None
        self._adapter = None
        self._vendor = None
        self._version = None
        self._health = None
        self.discriminator = None

        if uuid is not None:
            self.uuid = uuid
        if name is not None:
            self.name = name
        if description is not None:
            self.description = description
        if url is not None:
            self.url = url
        if disabled is not None:
            self.disabled = disabled
        if is_default is not None:
            self.is_default = is_default
        if auth is not None:
            self.auth = auth
        if access_credential is not None:
            self.access_credential = access_credential
        if skip_cert_verify is not None:
            self.skip_cert_verify = skip_cert_verify
        if use_internal_addr is not None:
            self.use_internal_addr = use_internal_addr
        if create_time is not None:
            self.create_time = create_time
        if update_time is not None:
            self.update_time = update_time
        if adapter is not None:
            self.adapter = adapter
        if vendor is not None:
            self.vendor = vendor
        if version is not None:
            self.version = version
        if health is not None:
            self.health = health

    @property
    def uuid(self):
        """Gets the uuid of this ScannerRegistration.  # noqa: E501

        The unique identifier of this registration.  # noqa: E501

        :return: The uuid of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this ScannerRegistration.

        The unique identifier of this registration.  # noqa: E501

        :param uuid: The uuid of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    @property
    def name(self):
        """Gets the name of this ScannerRegistration.  # noqa: E501

        The name of this registration.  # noqa: E501

        :return: The name of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ScannerRegistration.

        The name of this registration.  # noqa: E501

        :param name: The name of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """Gets the description of this ScannerRegistration.  # noqa: E501

        An optional description of this registration.  # noqa: E501

        :return: The description of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ScannerRegistration.

        An optional description of this registration.  # noqa: E501

        :param description: The description of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def url(self):
        """Gets the url of this ScannerRegistration.  # noqa: E501

        A base URL of the scanner adapter  # noqa: E501

        :return: The url of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ScannerRegistration.

        A base URL of the scanner adapter  # noqa: E501

        :param url: The url of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def disabled(self):
        """Gets the disabled of this ScannerRegistration.  # noqa: E501

        Indicate whether the registration is enabled or not  # noqa: E501

        :return: The disabled of this ScannerRegistration.  # noqa: E501
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """Sets the disabled of this ScannerRegistration.

        Indicate whether the registration is enabled or not  # noqa: E501

        :param disabled: The disabled of this ScannerRegistration.  # noqa: E501
        :type: bool
        """

        self._disabled = disabled

    @property
    def is_default(self):
        """Gets the is_default of this ScannerRegistration.  # noqa: E501

        Indicate if the registration is set as the system default one  # noqa: E501

        :return: The is_default of this ScannerRegistration.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this ScannerRegistration.

        Indicate if the registration is set as the system default one  # noqa: E501

        :param is_default: The is_default of this ScannerRegistration.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def auth(self):
        """Gets the auth of this ScannerRegistration.  # noqa: E501

        Specify what authentication approach is adopted for the HTTP communications. Supported types Basic\", \"Bearer\" and api key header \"X-ScannerAdapter-API-Key\"   # noqa: E501

        :return: The auth of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._auth

    @auth.setter
    def auth(self, auth):
        """Sets the auth of this ScannerRegistration.

        Specify what authentication approach is adopted for the HTTP communications. Supported types Basic\", \"Bearer\" and api key header \"X-ScannerAdapter-API-Key\"   # noqa: E501

        :param auth: The auth of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._auth = auth

    @property
    def access_credential(self):
        """Gets the access_credential of this ScannerRegistration.  # noqa: E501

        An optional value of the HTTP Authorization header sent with each request to the Scanner Adapter API.   # noqa: E501

        :return: The access_credential of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._access_credential

    @access_credential.setter
    def access_credential(self, access_credential):
        """Sets the access_credential of this ScannerRegistration.

        An optional value of the HTTP Authorization header sent with each request to the Scanner Adapter API.   # noqa: E501

        :param access_credential: The access_credential of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._access_credential = access_credential

    @property
    def skip_cert_verify(self):
        """Gets the skip_cert_verify of this ScannerRegistration.  # noqa: E501

        Indicate if skip the certificate verification when sending HTTP requests  # noqa: E501

        :return: The skip_cert_verify of this ScannerRegistration.  # noqa: E501
        :rtype: bool
        """
        return self._skip_cert_verify

    @skip_cert_verify.setter
    def skip_cert_verify(self, skip_cert_verify):
        """Sets the skip_cert_verify of this ScannerRegistration.

        Indicate if skip the certificate verification when sending HTTP requests  # noqa: E501

        :param skip_cert_verify: The skip_cert_verify of this ScannerRegistration.  # noqa: E501
        :type: bool
        """

        self._skip_cert_verify = skip_cert_verify

    @property
    def use_internal_addr(self):
        """Gets the use_internal_addr of this ScannerRegistration.  # noqa: E501

        Indicate whether use internal registry addr for the scanner to pull content or not  # noqa: E501

        :return: The use_internal_addr of this ScannerRegistration.  # noqa: E501
        :rtype: bool
        """
        return self._use_internal_addr

    @use_internal_addr.setter
    def use_internal_addr(self, use_internal_addr):
        """Sets the use_internal_addr of this ScannerRegistration.

        Indicate whether use internal registry addr for the scanner to pull content or not  # noqa: E501

        :param use_internal_addr: The use_internal_addr of this ScannerRegistration.  # noqa: E501
        :type: bool
        """

        self._use_internal_addr = use_internal_addr

    @property
    def create_time(self):
        """Gets the create_time of this ScannerRegistration.  # noqa: E501

        The creation time of this registration  # noqa: E501

        :return: The create_time of this ScannerRegistration.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this ScannerRegistration.

        The creation time of this registration  # noqa: E501

        :param create_time: The create_time of this ScannerRegistration.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    @property
    def update_time(self):
        """Gets the update_time of this ScannerRegistration.  # noqa: E501

        The update time of this registration  # noqa: E501

        :return: The update_time of this ScannerRegistration.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this ScannerRegistration.

        The update time of this registration  # noqa: E501

        :param update_time: The update_time of this ScannerRegistration.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    @property
    def adapter(self):
        """Gets the adapter of this ScannerRegistration.  # noqa: E501

        Optional property to describe the name of the scanner registration  # noqa: E501

        :return: The adapter of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._adapter

    @adapter.setter
    def adapter(self, adapter):
        """Sets the adapter of this ScannerRegistration.

        Optional property to describe the name of the scanner registration  # noqa: E501

        :param adapter: The adapter of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._adapter = adapter

    @property
    def vendor(self):
        """Gets the vendor of this ScannerRegistration.  # noqa: E501

        Optional property to describe the vendor of the scanner registration  # noqa: E501

        :return: The vendor of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._vendor

    @vendor.setter
    def vendor(self, vendor):
        """Sets the vendor of this ScannerRegistration.

        Optional property to describe the vendor of the scanner registration  # noqa: E501

        :param vendor: The vendor of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._vendor = vendor

    @property
    def version(self):
        """Gets the version of this ScannerRegistration.  # noqa: E501

        Optional property to describe the version of the scanner registration  # noqa: E501

        :return: The version of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ScannerRegistration.

        Optional property to describe the version of the scanner registration  # noqa: E501

        :param version: The version of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def health(self):
        """Gets the health of this ScannerRegistration.  # noqa: E501

        Indicate the healthy of the registration  # noqa: E501

        :return: The health of this ScannerRegistration.  # noqa: E501
        :rtype: str
        """
        return self._health

    @health.setter
    def health(self, health):
        """Sets the health of this ScannerRegistration.

        Indicate the healthy of the registration  # noqa: E501

        :param health: The health of this ScannerRegistration.  # noqa: E501
        :type: str
        """

        self._health = health

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScannerRegistration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScannerRegistration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScannerRegistration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ScanDataExportExecution(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'user_id': 'int',
        'status': 'str',
        'trigger': 'str',
        'start_time': 'datetime',
        'end_time': 'datetime',
        'status_text': 'str',
        'user_name': 'str',
        'file_present': 'bool'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'user_id',
        'status': 'status',
        'trigger': 'trigger',
        'start_time': 'start_time',
        'end_time': 'end_time',
        'status_text': 'status_text',
        'user_name': 'user_name',
        'file_present': 'file_present'
    }

    def __init__(self, id=None, user_id=None, status=None, trigger=None, start_time=None, end_time=None, status_text=None, user_name=None, file_present=None, _configuration=None):  # noqa: E501
        """ScanDataExportExecution - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._user_id = None
        self._status = None
        self._trigger = None
        self._start_time = None
        self._end_time = None
        self._status_text = None
        self._user_name = None
        self._file_present = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if user_id is not None:
            self.user_id = user_id
        if status is not None:
            self.status = status
        if trigger is not None:
            self.trigger = trigger
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time
        if status_text is not None:
            self.status_text = status_text
        if user_name is not None:
            self.user_name = user_name
        if file_present is not None:
            self.file_present = file_present

    @property
    def id(self):
        """Gets the id of this ScanDataExportExecution.  # noqa: E501

        The ID of the execution  # noqa: E501

        :return: The id of this ScanDataExportExecution.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ScanDataExportExecution.

        The ID of the execution  # noqa: E501

        :param id: The id of this ScanDataExportExecution.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this ScanDataExportExecution.  # noqa: E501

        The ID if the user triggering the export job  # noqa: E501

        :return: The user_id of this ScanDataExportExecution.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ScanDataExportExecution.

        The ID if the user triggering the export job  # noqa: E501

        :param user_id: The user_id of this ScanDataExportExecution.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def status(self):
        """Gets the status of this ScanDataExportExecution.  # noqa: E501

        The status of the execution  # noqa: E501

        :return: The status of this ScanDataExportExecution.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this ScanDataExportExecution.

        The status of the execution  # noqa: E501

        :param status: The status of this ScanDataExportExecution.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def trigger(self):
        """Gets the trigger of this ScanDataExportExecution.  # noqa: E501

        The trigger mode  # noqa: E501

        :return: The trigger of this ScanDataExportExecution.  # noqa: E501
        :rtype: str
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this ScanDataExportExecution.

        The trigger mode  # noqa: E501

        :param trigger: The trigger of this ScanDataExportExecution.  # noqa: E501
        :type: str
        """

        self._trigger = trigger

    @property
    def start_time(self):
        """Gets the start_time of this ScanDataExportExecution.  # noqa: E501

        The start time  # noqa: E501

        :return: The start_time of this ScanDataExportExecution.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ScanDataExportExecution.

        The start time  # noqa: E501

        :param start_time: The start_time of this ScanDataExportExecution.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this ScanDataExportExecution.  # noqa: E501

        The end time  # noqa: E501

        :return: The end_time of this ScanDataExportExecution.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this ScanDataExportExecution.

        The end time  # noqa: E501

        :param end_time: The end_time of this ScanDataExportExecution.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def status_text(self):
        """Gets the status_text of this ScanDataExportExecution.  # noqa: E501

        The status text  # noqa: E501

        :return: The status_text of this ScanDataExportExecution.  # noqa: E501
        :rtype: str
        """
        return self._status_text

    @status_text.setter
    def status_text(self, status_text):
        """Sets the status_text of this ScanDataExportExecution.

        The status text  # noqa: E501

        :param status_text: The status_text of this ScanDataExportExecution.  # noqa: E501
        :type: str
        """

        self._status_text = status_text

    @property
    def user_name(self):
        """Gets the user_name of this ScanDataExportExecution.  # noqa: E501

        The name of the user triggering the job  # noqa: E501

        :return: The user_name of this ScanDataExportExecution.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this ScanDataExportExecution.

        The name of the user triggering the job  # noqa: E501

        :param user_name: The user_name of this ScanDataExportExecution.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def file_present(self):
        """Gets the file_present of this ScanDataExportExecution.  # noqa: E501

        Indicates whether the export artifact is present in registry  # noqa: E501

        :return: The file_present of this ScanDataExportExecution.  # noqa: E501
        :rtype: bool
        """
        return self._file_present

    @file_present.setter
    def file_present(self, file_present):
        """Sets the file_present of this ScanDataExportExecution.

        Indicates whether the export artifact is present in registry  # noqa: E501

        :param file_present: The file_present of this ScanDataExportExecution.  # noqa: E501
        :type: bool
        """

        self._file_present = file_present

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ScanDataExportExecution, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScanDataExportExecution):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScanDataExportExecution):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ChartMetadata(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'home': 'str',
        'sources': 'list[str]',
        'version': 'str',
        'description': 'str',
        'keywords': 'list[str]',
        'engine': 'str',
        'icon': 'str',
        'api_version': 'str',
        'app_version': 'str',
        'deprecated': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'home': 'home',
        'sources': 'sources',
        'version': 'version',
        'description': 'description',
        'keywords': 'keywords',
        'engine': 'engine',
        'icon': 'icon',
        'api_version': 'apiVersion',
        'app_version': 'appVersion',
        'deprecated': 'deprecated'
    }

    def __init__(self, name=None, home=None, sources=None, version=None, description=None, keywords=None, engine=None, icon=None, api_version=None, app_version=None, deprecated=None, _configuration=None):  # noqa: E501
        """ChartMetadata - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._home = None
        self._sources = None
        self._version = None
        self._description = None
        self._keywords = None
        self._engine = None
        self._icon = None
        self._api_version = None
        self._app_version = None
        self._deprecated = None
        self.discriminator = None

        self.name = name
        if home is not None:
            self.home = home
        if sources is not None:
            self.sources = sources
        self.version = version
        if description is not None:
            self.description = description
        if keywords is not None:
            self.keywords = keywords
        self.engine = engine
        self.icon = icon
        self.api_version = api_version
        self.app_version = app_version
        if deprecated is not None:
            self.deprecated = deprecated

    @property
    def name(self):
        """Gets the name of this ChartMetadata.  # noqa: E501

        The name of the chart  # noqa: E501

        :return: The name of this ChartMetadata.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ChartMetadata.

        The name of the chart  # noqa: E501

        :param name: The name of this ChartMetadata.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def home(self):
        """Gets the home of this ChartMetadata.  # noqa: E501

        The URL to the relevant project page  # noqa: E501

        :return: The home of this ChartMetadata.  # noqa: E501
        :rtype: str
        """
        return self._home

    @home.setter
    def home(self, home):
        """Sets the home of this ChartMetadata.

        The URL to the relevant project page  # noqa: E501

        :param home: The home of this ChartMetadata.  # noqa: E501
        :type: str
        """

        self._home = home

    @property
    def sources(self):
        """Gets the sources of this ChartMetadata.  # noqa: E501

        The URL to the source code of chart  # noqa: E501

        :return: The sources of this ChartMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._sources

    @sources.setter
    def sources(self, sources):
        """Sets the sources of this ChartMetadata.

        The URL to the source code of chart  # noqa: E501

        :param sources: The sources of this ChartMetadata.  # noqa: E501
        :type: list[str]
        """

        self._sources = sources

    @property
    def version(self):
        """Gets the version of this ChartMetadata.  # noqa: E501

        A SemVer 2 version of chart  # noqa: E501

        :return: The version of this ChartMetadata.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ChartMetadata.

        A SemVer 2 version of chart  # noqa: E501

        :param version: The version of this ChartMetadata.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def description(self):
        """Gets the description of this ChartMetadata.  # noqa: E501

        A one-sentence description of chart  # noqa: E501

        :return: The description of this ChartMetadata.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ChartMetadata.

        A one-sentence description of chart  # noqa: E501

        :param description: The description of this ChartMetadata.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def keywords(self):
        """Gets the keywords of this ChartMetadata.  # noqa: E501

        A list of string keywords  # noqa: E501

        :return: The keywords of this ChartMetadata.  # noqa: E501
        :rtype: list[str]
        """
        return self._keywords

    @keywords.setter
    def keywords(self, keywords):
        """Sets the keywords of this ChartMetadata.

        A list of string keywords  # noqa: E501

        :param keywords: The keywords of this ChartMetadata.  # noqa: E501
        :type: list[str]
        """

        self._keywords = keywords

    @property
    def engine(self):
        """Gets the engine of this ChartMetadata.  # noqa: E501

        The name of template engine  # noqa: E501

        :return: The engine of this ChartMetadata.  # noqa: E501
        :rtype: str
        """
        return self._engine

    @engine.setter
    def engine(self, engine):
        """Sets the engine of this ChartMetadata.

        The name of template engine  # noqa: E501

        :param engine: The engine of this ChartMetadata.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and engine is None:
            raise ValueError("Invalid value for `engine`, must not be `None`")  # noqa: E501

        self._engine = engine

    @property
    def icon(self):
        """Gets the icon of this ChartMetadata.  # noqa: E501

        The URL to an icon file  # noqa: E501

        :return: The icon of this ChartMetadata.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this ChartMetadata.

        The URL to an icon file  # noqa: E501

        :param icon: The icon of this ChartMetadata.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and icon is None:
            raise ValueError("Invalid value for `icon`, must not be `None`")  # noqa: E501

        self._icon = icon

    @property
    def api_version(self):
        """Gets the api_version of this ChartMetadata.  # noqa: E501

        The API version of this chart  # noqa: E501

        :return: The api_version of this ChartMetadata.  # noqa: E501
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this ChartMetadata.

        The API version of this chart  # noqa: E501

        :param api_version: The api_version of this ChartMetadata.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and api_version is None:
            raise ValueError("Invalid value for `api_version`, must not be `None`")  # noqa: E501

        self._api_version = api_version

    @property
    def app_version(self):
        """Gets the app_version of this ChartMetadata.  # noqa: E501

        The version of the application enclosed in the chart  # noqa: E501

        :return: The app_version of this ChartMetadata.  # noqa: E501
        :rtype: str
        """
        return self._app_version

    @app_version.setter
    def app_version(self, app_version):
        """Sets the app_version of this ChartMetadata.

        The version of the application enclosed in the chart  # noqa: E501

        :param app_version: The app_version of this ChartMetadata.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and app_version is None:
            raise ValueError("Invalid value for `app_version`, must not be `None`")  # noqa: E501

        self._app_version = app_version

    @property
    def deprecated(self):
        """Gets the deprecated of this ChartMetadata.  # noqa: E501

        Whether or not this chart is deprecated  # noqa: E501

        :return: The deprecated of this ChartMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._deprecated

    @deprecated.setter
    def deprecated(self, deprecated):
        """Sets the deprecated of this ChartMetadata.

        Whether or not this chart is deprecated  # noqa: E501

        :param deprecated: The deprecated of this ChartMetadata.  # noqa: E501
        :type: bool
        """

        self._deprecated = deprecated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ChartMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChartMetadata):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChartMetadata):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harbor_client.api_client import ApiClient


class SysteminfoApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_cert(self, **kwargs):  # noqa: E501
        """Get default root certificate.  # noqa: E501

        This endpoint is for downloading a default root certificate.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cert(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_cert_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_cert_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_cert_with_http_info(self, **kwargs):  # noqa: E501
        """Get default root certificate.  # noqa: E501

        This endpoint is for downloading a default root certificate.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_cert_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_cert" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_cert`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/octet-stream'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/systeminfo/getcert', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_system_info(self, **kwargs):  # noqa: E501
        """Get general system info  # noqa: E501

        This API is for retrieving general system info, this can be called by anonymous request.  Some attributes will be omitted in the response when this API is called by anonymous request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: GeneralInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_system_info_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_system_info_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_system_info_with_http_info(self, **kwargs):  # noqa: E501
        """Get general system info  # noqa: E501

        This API is for retrieving general system info, this can be called by anonymous request.  Some attributes will be omitted in the response when this API is called by anonymous request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_system_info_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: GeneralInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_system_info" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_system_info`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/systeminfo', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GeneralInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_volumes(self, **kwargs):  # noqa: E501
        """Get system volume info (total/free size).  # noqa: E501

        This endpoint is for retrieving system volume info that only provides for admin user.  Note that the response only reflects the storage status of local disk.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_volumes(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: SystemInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_volumes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_volumes_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_volumes_with_http_info(self, **kwargs):  # noqa: E501
        """Get system volume info (total/free size).  # noqa: E501

        This endpoint is for retrieving system volume info that only provides for admin user.  Note that the response only reflects the storage status of local disk.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_volumes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: SystemInfo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_volumes" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_volumes`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/systeminfo/volumes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SystemInfo',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harbor_client.api_client import ApiClient


class UsergroupApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_user_group(self, **kwargs):  # noqa: E501
        """Create user group  # noqa: E501

        Create user group information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_group(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param UserGroup usergroup:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_user_group_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_user_group_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_user_group_with_http_info(self, **kwargs):  # noqa: E501
        """Create user group  # noqa: E501

        Create user group information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_user_group_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param UserGroup usergroup:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id', 'usergroup']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_user_group" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `create_user_group`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'usergroup' in params:
            body_params = params['usergroup']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/usergroups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_user_group(self, group_id, **kwargs):  # noqa: E501
        """Delete user group  # noqa: E501

        Delete user group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int group_id: (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_user_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_user_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def delete_user_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Delete user group  # noqa: E501

        Delete user group  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_user_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int group_id: (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `delete_user_group`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `delete_user_group`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['group_id'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/usergroups/{group_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_user_group(self, group_id, **kwargs):  # noqa: E501
        """Get user group information  # noqa: E501

        Get user group information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int group_id: Group ID (required)
        :param str x_request_id: An unique ID for the request
        :return: UserGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_user_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_user_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def get_user_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Get user group information  # noqa: E501

        Get user group information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_user_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int group_id: Group ID (required)
        :param str x_request_id: An unique ID for the request
        :return: UserGroup
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `get_user_group`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_user_group`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['group_id'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/usergroups/{group_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UserGroup',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_user_groups(self, **kwargs):  # noqa: E501
        """Get all user groups information  # noqa: E501

        Get all user groups information, it is open for system admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_user_groups(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param int page: The page number
        :param int page_size: The size of per page
        :param str ldap_group_dn: search with ldap group DN
        :param str group_name: group name need to search, fuzzy matches
        :return: list[UserGroup]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_user_groups_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_user_groups_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_user_groups_with_http_info(self, **kwargs):  # noqa: E501
        """Get all user groups information  # noqa: E501

        Get all user groups information, it is open for system admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_user_groups_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :param int page: The page number
        :param int page_size: The size of per page
        :param str ldap_group_dn: search with ldap group DN
        :param str group_name: group name need to search, fuzzy matches
        :return: list[UserGroup]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id', 'page', 'page_size', 'ldap_group_dn', 'group_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_user_groups" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `list_user_groups`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('page_size' in params and params['page_size'] > 100):  # noqa: E501
            raise ValueError("Invalid value for parameter `page_size` when calling `list_user_groups`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('page_size', params['page_size']))  # noqa: E501
        if 'ldap_group_dn' in params:
            query_params.append(('ldap_group_dn', params['ldap_group_dn']))  # noqa: E501
        if 'group_name' in params:
            query_params.append(('group_name', params['group_name']))  # noqa: E501

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/usergroups', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserGroup]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def search_user_groups(self, groupname, **kwargs):  # noqa: E501
        """Search groups by groupname  # noqa: E501

        This endpoint is to search groups by group name.  It's open for all authenticated requests.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_user_groups(groupname, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str groupname: Group name for filtering results. (required)
        :param str x_request_id: An unique ID for the request
        :param int page: The page number
        :param int page_size: The size of per page
        :return: list[UserGroupSearchItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.search_user_groups_with_http_info(groupname, **kwargs)  # noqa: E501
        else:
            (data) = self.search_user_groups_with_http_info(groupname, **kwargs)  # noqa: E501
            return data

    def search_user_groups_with_http_info(self, groupname, **kwargs):  # noqa: E501
        """Search groups by groupname  # noqa: E501

        This endpoint is to search groups by group name.  It's open for all authenticated requests.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.search_user_groups_with_http_info(groupname, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str groupname: Group name for filtering results. (required)
        :param str x_request_id: An unique ID for the request
        :param int page: The page number
        :param int page_size: The size of per page
        :return: list[UserGroupSearchItem]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['groupname', 'x_request_id', 'page', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search_user_groups" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'groupname' is set
        if self.api_client.client_side_validation and ('groupname' not in params or
                                                       params['groupname'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `groupname` when calling `search_user_groups`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `search_user_groups`, length must be greater than or equal to `1`")  # noqa: E501
        if self.api_client.client_side_validation and ('page_size' in params and params['page_size'] > 100):  # noqa: E501
            raise ValueError("Invalid value for parameter `page_size` when calling `search_user_groups`, must be a value less than or equal to `100`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('page_size', params['page_size']))  # noqa: E501
        if 'groupname' in params:
            query_params.append(('groupname', params['groupname']))  # noqa: E501

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/usergroups/search', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[UserGroupSearchItem]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_user_group(self, group_id, **kwargs):  # noqa: E501
        """Update group information  # noqa: E501

        Update user group information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int group_id: Group ID (required)
        :param str x_request_id: An unique ID for the request
        :param UserGroup usergroup:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_user_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_user_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def update_user_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Update group information  # noqa: E501

        Update user group information  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_user_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int group_id: Group ID (required)
        :param str x_request_id: An unique ID for the request
        :param UserGroup usergroup:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'x_request_id', 'usergroup']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_user_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `update_user_group`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `update_user_group`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['group_id'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'usergroup' in params:
            body_params = params['usergroup']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/usergroups/{group_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from harbor_client.ldap_api import LdapApi
from harbor_client.retention_api import RetentionApi
from harbor_client.system_cve_allowlist_api import SystemCVEAllowlistApi
from harbor_client.artifact_api import ArtifactApi
from harbor_client.auditlog_api import AuditlogApi
from harbor_client.configure_api import ConfigureApi
from harbor_client.gc_api import GcApi
from harbor_client.health_api import HealthApi
from harbor_client.icon_api import IconApi
from harbor_client.immutable_api import ImmutableApi
from harbor_client.jobservice_api import JobserviceApi
from harbor_client.label_api import LabelApi
from harbor_client.member_api import MemberApi
from harbor_client.oidc_api import OidcApi
from harbor_client.ping_api import PingApi
from harbor_client.preheat_api import PreheatApi
from harbor_client.project_api import ProjectApi
from harbor_client.project_metadata_api import ProjectMetadataApi
from harbor_client.purge_api import PurgeApi
from harbor_client.quota_api import QuotaApi
from harbor_client.registry_api import RegistryApi
from harbor_client.replication_api import ReplicationApi
from harbor_client.repository_api import RepositoryApi
from harbor_client.robot_api import RobotApi
from harbor_client.robotv1_api import Robotv1Api
from harbor_client.scan_api import ScanApi
from harbor_client.scan_all_api import ScanAllApi
from harbor_client.scan_data_export_api import ScanDataExportApi
from harbor_client.scanner_api import ScannerApi
from harbor_client.schedule_api import ScheduleApi
from harbor_client.search_api import SearchApi
from harbor_client.statistic_api import StatisticApi
from harbor_client.systeminfo_api import SysteminfoApi
from harbor_client.user_api import UserApi
from harbor_client.usergroup_api import UsergroupApi
from harbor_client.webhook_api import WebhookApi
from harbor_client.webhookjob_api import WebhookjobApi



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class Worker(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'pool_id': 'str',
        'job_name': 'str',
        'job_id': 'str',
        'start_at': 'datetime',
        'check_in': 'str',
        'checkin_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'pool_id': 'pool_id',
        'job_name': 'job_name',
        'job_id': 'job_id',
        'start_at': 'start_at',
        'check_in': 'check_in',
        'checkin_at': 'checkin_at'
    }

    def __init__(self, id=None, pool_id=None, job_name=None, job_id=None, start_at=None, check_in=None, checkin_at=None, _configuration=None):  # noqa: E501
        """Worker - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._pool_id = None
        self._job_name = None
        self._job_id = None
        self._start_at = None
        self._check_in = None
        self._checkin_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if pool_id is not None:
            self.pool_id = pool_id
        if job_name is not None:
            self.job_name = job_name
        if job_id is not None:
            self.job_id = job_id
        if start_at is not None:
            self.start_at = start_at
        if check_in is not None:
            self.check_in = check_in
        if checkin_at is not None:
            self.checkin_at = checkin_at

    @property
    def id(self):
        """Gets the id of this Worker.  # noqa: E501

        the id of the worker  # noqa: E501

        :return: The id of this Worker.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Worker.

        the id of the worker  # noqa: E501

        :param id: The id of this Worker.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def pool_id(self):
        """Gets the pool_id of this Worker.  # noqa: E501

        the id of the worker pool  # noqa: E501

        :return: The pool_id of this Worker.  # noqa: E501
        :rtype: str
        """
        return self._pool_id

    @pool_id.setter
    def pool_id(self, pool_id):
        """Sets the pool_id of this Worker.

        the id of the worker pool  # noqa: E501

        :param pool_id: The pool_id of this Worker.  # noqa: E501
        :type: str
        """

        self._pool_id = pool_id

    @property
    def job_name(self):
        """Gets the job_name of this Worker.  # noqa: E501

        the name of the running job in the worker  # noqa: E501

        :return: The job_name of this Worker.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this Worker.

        the name of the running job in the worker  # noqa: E501

        :param job_name: The job_name of this Worker.  # noqa: E501
        :type: str
        """

        self._job_name = job_name

    @property
    def job_id(self):
        """Gets the job_id of this Worker.  # noqa: E501

        the id of the running job in the worker  # noqa: E501

        :return: The job_id of this Worker.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this Worker.

        the id of the running job in the worker  # noqa: E501

        :param job_id: The job_id of this Worker.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def start_at(self):
        """Gets the start_at of this Worker.  # noqa: E501

        The start time of the worker  # noqa: E501

        :return: The start_at of this Worker.  # noqa: E501
        :rtype: datetime
        """
        return self._start_at

    @start_at.setter
    def start_at(self, start_at):
        """Sets the start_at of this Worker.

        The start time of the worker  # noqa: E501

        :param start_at: The start_at of this Worker.  # noqa: E501
        :type: datetime
        """

        self._start_at = start_at

    @property
    def check_in(self):
        """Gets the check_in of this Worker.  # noqa: E501

        the checkin of the running job in the worker  # noqa: E501

        :return: The check_in of this Worker.  # noqa: E501
        :rtype: str
        """
        return self._check_in

    @check_in.setter
    def check_in(self, check_in):
        """Sets the check_in of this Worker.

        the checkin of the running job in the worker  # noqa: E501

        :param check_in: The check_in of this Worker.  # noqa: E501
        :type: str
        """

        self._check_in = check_in

    @property
    def checkin_at(self):
        """Gets the checkin_at of this Worker.  # noqa: E501

        The checkin time of the worker  # noqa: E501

        :return: The checkin_at of this Worker.  # noqa: E501
        :rtype: datetime
        """
        return self._checkin_at

    @checkin_at.setter
    def checkin_at(self, checkin_at):
        """Sets the checkin_at of this Worker.

        The checkin time of the worker  # noqa: E501

        :param checkin_at: The checkin_at of this Worker.  # noqa: E501
        :type: datetime
        """

        self._checkin_at = checkin_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Worker, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Worker):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Worker):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class UserResp(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'realname': 'str',
        'comment': 'str',
        'user_id': 'int',
        'username': 'str',
        'sysadmin_flag': 'bool',
        'admin_role_in_auth': 'bool',
        'oidc_user_meta': 'OIDCUserInfo',
        'creation_time': 'datetime',
        'update_time': 'datetime'
    }

    attribute_map = {
        'email': 'email',
        'realname': 'realname',
        'comment': 'comment',
        'user_id': 'user_id',
        'username': 'username',
        'sysadmin_flag': 'sysadmin_flag',
        'admin_role_in_auth': 'admin_role_in_auth',
        'oidc_user_meta': 'oidc_user_meta',
        'creation_time': 'creation_time',
        'update_time': 'update_time'
    }

    def __init__(self, email=None, realname=None, comment=None, user_id=None, username=None, sysadmin_flag=None, admin_role_in_auth=None, oidc_user_meta=None, creation_time=None, update_time=None, _configuration=None):  # noqa: E501
        """UserResp - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._email = None
        self._realname = None
        self._comment = None
        self._user_id = None
        self._username = None
        self._sysadmin_flag = None
        self._admin_role_in_auth = None
        self._oidc_user_meta = None
        self._creation_time = None
        self._update_time = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if realname is not None:
            self.realname = realname
        if comment is not None:
            self.comment = comment
        if user_id is not None:
            self.user_id = user_id
        if username is not None:
            self.username = username
        if sysadmin_flag is not None:
            self.sysadmin_flag = sysadmin_flag
        if admin_role_in_auth is not None:
            self.admin_role_in_auth = admin_role_in_auth
        if oidc_user_meta is not None:
            self.oidc_user_meta = oidc_user_meta
        if creation_time is not None:
            self.creation_time = creation_time
        if update_time is not None:
            self.update_time = update_time

    @property
    def email(self):
        """Gets the email of this UserResp.  # noqa: E501


        :return: The email of this UserResp.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this UserResp.


        :param email: The email of this UserResp.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def realname(self):
        """Gets the realname of this UserResp.  # noqa: E501


        :return: The realname of this UserResp.  # noqa: E501
        :rtype: str
        """
        return self._realname

    @realname.setter
    def realname(self, realname):
        """Sets the realname of this UserResp.


        :param realname: The realname of this UserResp.  # noqa: E501
        :type: str
        """

        self._realname = realname

    @property
    def comment(self):
        """Gets the comment of this UserResp.  # noqa: E501


        :return: The comment of this UserResp.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this UserResp.


        :param comment: The comment of this UserResp.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def user_id(self):
        """Gets the user_id of this UserResp.  # noqa: E501


        :return: The user_id of this UserResp.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserResp.


        :param user_id: The user_id of this UserResp.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def username(self):
        """Gets the username of this UserResp.  # noqa: E501


        :return: The username of this UserResp.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this UserResp.


        :param username: The username of this UserResp.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def sysadmin_flag(self):
        """Gets the sysadmin_flag of this UserResp.  # noqa: E501


        :return: The sysadmin_flag of this UserResp.  # noqa: E501
        :rtype: bool
        """
        return self._sysadmin_flag

    @sysadmin_flag.setter
    def sysadmin_flag(self, sysadmin_flag):
        """Sets the sysadmin_flag of this UserResp.


        :param sysadmin_flag: The sysadmin_flag of this UserResp.  # noqa: E501
        :type: bool
        """

        self._sysadmin_flag = sysadmin_flag

    @property
    def admin_role_in_auth(self):
        """Gets the admin_role_in_auth of this UserResp.  # noqa: E501

        indicate the admin privilege is grant by authenticator (LDAP), is always false unless it is the current login user  # noqa: E501

        :return: The admin_role_in_auth of this UserResp.  # noqa: E501
        :rtype: bool
        """
        return self._admin_role_in_auth

    @admin_role_in_auth.setter
    def admin_role_in_auth(self, admin_role_in_auth):
        """Sets the admin_role_in_auth of this UserResp.

        indicate the admin privilege is grant by authenticator (LDAP), is always false unless it is the current login user  # noqa: E501

        :param admin_role_in_auth: The admin_role_in_auth of this UserResp.  # noqa: E501
        :type: bool
        """

        self._admin_role_in_auth = admin_role_in_auth

    @property
    def oidc_user_meta(self):
        """Gets the oidc_user_meta of this UserResp.  # noqa: E501


        :return: The oidc_user_meta of this UserResp.  # noqa: E501
        :rtype: OIDCUserInfo
        """
        return self._oidc_user_meta

    @oidc_user_meta.setter
    def oidc_user_meta(self, oidc_user_meta):
        """Sets the oidc_user_meta of this UserResp.


        :param oidc_user_meta: The oidc_user_meta of this UserResp.  # noqa: E501
        :type: OIDCUserInfo
        """

        self._oidc_user_meta = oidc_user_meta

    @property
    def creation_time(self):
        """Gets the creation_time of this UserResp.  # noqa: E501

        The creation time of the user.  # noqa: E501

        :return: The creation_time of this UserResp.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this UserResp.

        The creation time of the user.  # noqa: E501

        :param creation_time: The creation_time of this UserResp.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def update_time(self):
        """Gets the update_time of this UserResp.  # noqa: E501

        The update time of the user.  # noqa: E501

        :return: The update_time of this UserResp.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this UserResp.

        The update time of the user.  # noqa: E501

        :param update_time: The update_time of this UserResp.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserResp, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserResp):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserResp):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class WorkerPool(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pid': 'int',
        'worker_pool_id': 'str',
        'start_at': 'datetime',
        'heartbeat_at': 'datetime',
        'concurrency': 'int',
        'host': 'str'
    }

    attribute_map = {
        'pid': 'pid',
        'worker_pool_id': 'worker_pool_id',
        'start_at': 'start_at',
        'heartbeat_at': 'heartbeat_at',
        'concurrency': 'concurrency',
        'host': 'host'
    }

    def __init__(self, pid=None, worker_pool_id=None, start_at=None, heartbeat_at=None, concurrency=None, host=None, _configuration=None):  # noqa: E501
        """WorkerPool - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._pid = None
        self._worker_pool_id = None
        self._start_at = None
        self._heartbeat_at = None
        self._concurrency = None
        self._host = None
        self.discriminator = None

        if pid is not None:
            self.pid = pid
        if worker_pool_id is not None:
            self.worker_pool_id = worker_pool_id
        if start_at is not None:
            self.start_at = start_at
        if heartbeat_at is not None:
            self.heartbeat_at = heartbeat_at
        if concurrency is not None:
            self.concurrency = concurrency
        if host is not None:
            self.host = host

    @property
    def pid(self):
        """Gets the pid of this WorkerPool.  # noqa: E501

        the process id of jobservice  # noqa: E501

        :return: The pid of this WorkerPool.  # noqa: E501
        :rtype: int
        """
        return self._pid

    @pid.setter
    def pid(self, pid):
        """Sets the pid of this WorkerPool.

        the process id of jobservice  # noqa: E501

        :param pid: The pid of this WorkerPool.  # noqa: E501
        :type: int
        """

        self._pid = pid

    @property
    def worker_pool_id(self):
        """Gets the worker_pool_id of this WorkerPool.  # noqa: E501

        the id of the worker pool  # noqa: E501

        :return: The worker_pool_id of this WorkerPool.  # noqa: E501
        :rtype: str
        """
        return self._worker_pool_id

    @worker_pool_id.setter
    def worker_pool_id(self, worker_pool_id):
        """Sets the worker_pool_id of this WorkerPool.

        the id of the worker pool  # noqa: E501

        :param worker_pool_id: The worker_pool_id of this WorkerPool.  # noqa: E501
        :type: str
        """

        self._worker_pool_id = worker_pool_id

    @property
    def start_at(self):
        """Gets the start_at of this WorkerPool.  # noqa: E501

        The start time of the work pool  # noqa: E501

        :return: The start_at of this WorkerPool.  # noqa: E501
        :rtype: datetime
        """
        return self._start_at

    @start_at.setter
    def start_at(self, start_at):
        """Sets the start_at of this WorkerPool.

        The start time of the work pool  # noqa: E501

        :param start_at: The start_at of this WorkerPool.  # noqa: E501
        :type: datetime
        """

        self._start_at = start_at

    @property
    def heartbeat_at(self):
        """Gets the heartbeat_at of this WorkerPool.  # noqa: E501

        The heartbeat time of the work pool  # noqa: E501

        :return: The heartbeat_at of this WorkerPool.  # noqa: E501
        :rtype: datetime
        """
        return self._heartbeat_at

    @heartbeat_at.setter
    def heartbeat_at(self, heartbeat_at):
        """Sets the heartbeat_at of this WorkerPool.

        The heartbeat time of the work pool  # noqa: E501

        :param heartbeat_at: The heartbeat_at of this WorkerPool.  # noqa: E501
        :type: datetime
        """

        self._heartbeat_at = heartbeat_at

    @property
    def concurrency(self):
        """Gets the concurrency of this WorkerPool.  # noqa: E501

        The concurrency of the work pool  # noqa: E501

        :return: The concurrency of this WorkerPool.  # noqa: E501
        :rtype: int
        """
        return self._concurrency

    @concurrency.setter
    def concurrency(self, concurrency):
        """Sets the concurrency of this WorkerPool.

        The concurrency of the work pool  # noqa: E501

        :param concurrency: The concurrency of this WorkerPool.  # noqa: E501
        :type: int
        """

        self._concurrency = concurrency

    @property
    def host(self):
        """Gets the host of this WorkerPool.  # noqa: E501

        The host of the work pool  # noqa: E501

        :return: The host of this WorkerPool.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this WorkerPool.

        The host of the work pool  # noqa: E501

        :param host: The host of this WorkerPool.  # noqa: E501
        :type: str
        """

        self._host = host

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkerPool, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkerPool):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkerPool):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from harbor_client.api_client import ApiClient


class JobserviceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def action_pending_jobs(self, job_type, action_request, **kwargs):  # noqa: E501
        """stop and clean, pause, resume pending jobs in the queue  # noqa: E501

        stop and clean, pause, resume pending jobs in the queue  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.action_pending_jobs(job_type, action_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_type: The type of the job. 'all' stands for all job types (required)
        :param ActionRequest action_request: (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.action_pending_jobs_with_http_info(job_type, action_request, **kwargs)  # noqa: E501
        else:
            (data) = self.action_pending_jobs_with_http_info(job_type, action_request, **kwargs)  # noqa: E501
            return data

    def action_pending_jobs_with_http_info(self, job_type, action_request, **kwargs):  # noqa: E501
        """stop and clean, pause, resume pending jobs in the queue  # noqa: E501

        stop and clean, pause, resume pending jobs in the queue  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.action_pending_jobs_with_http_info(job_type, action_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_type: The type of the job. 'all' stands for all job types (required)
        :param ActionRequest action_request: (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_type', 'action_request', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method action_pending_jobs" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_type' is set
        if self.api_client.client_side_validation and ('job_type' not in params or
                                                       params['job_type'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `job_type` when calling `action_pending_jobs`")  # noqa: E501
        # verify the required parameter 'action_request' is set
        if self.api_client.client_side_validation and ('action_request' not in params or
                                                       params['action_request'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `action_request` when calling `action_pending_jobs`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `action_pending_jobs`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'job_type' in params:
            path_params['job_type'] = params['job_type']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        if 'action_request' in params:
            body_params = params['action_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/jobservice/queues/{job_type}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_worker_pools(self, **kwargs):  # noqa: E501
        """Get worker pools  # noqa: E501

        Get worker pools  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_worker_pools(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: list[WorkerPool]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_worker_pools_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_worker_pools_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_worker_pools_with_http_info(self, **kwargs):  # noqa: E501
        """Get worker pools  # noqa: E501

        Get worker pools  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_worker_pools_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: list[WorkerPool]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_worker_pools" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_worker_pools`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/jobservice/pools', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[WorkerPool]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_workers(self, pool_id, **kwargs):  # noqa: E501
        """Get workers  # noqa: E501

        Get workers in current pool  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workers(pool_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool_id: The name of the pool. 'all' stands for all pools (required)
        :param str x_request_id: An unique ID for the request
        :return: list[Worker]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_workers_with_http_info(pool_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_workers_with_http_info(pool_id, **kwargs)  # noqa: E501
            return data

    def get_workers_with_http_info(self, pool_id, **kwargs):  # noqa: E501
        """Get workers  # noqa: E501

        Get workers in current pool  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_workers_with_http_info(pool_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str pool_id: The name of the pool. 'all' stands for all pools (required)
        :param str x_request_id: An unique ID for the request
        :return: list[Worker]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['pool_id', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workers" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'pool_id' is set
        if self.api_client.client_side_validation and ('pool_id' not in params or
                                                       params['pool_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `pool_id` when calling `get_workers`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `get_workers`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'pool_id' in params:
            path_params['pool_id'] = params['pool_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/jobservice/pools/{pool_id}/workers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Worker]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_job_queues(self, **kwargs):  # noqa: E501
        """list job queues  # noqa: E501

        list job queue  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_job_queues(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: list[JobQueue]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_job_queues_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_job_queues_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_job_queues_with_http_info(self, **kwargs):  # noqa: E501
        """list job queues  # noqa: E501

        list job queue  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_job_queues_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_request_id: An unique ID for the request
        :return: list[JobQueue]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_job_queues" % key
                )
            params[key] = val
        del params['kwargs']

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `list_job_queues`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/jobservice/queues', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[JobQueue]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def stop_running_job(self, job_id, **kwargs):  # noqa: E501
        """Stop running job  # noqa: E501

        Stop running job  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_running_job(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: The id of the job. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.stop_running_job_with_http_info(job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.stop_running_job_with_http_info(job_id, **kwargs)  # noqa: E501
            return data

    def stop_running_job_with_http_info(self, job_id, **kwargs):  # noqa: E501
        """Stop running job  # noqa: E501

        Stop running job  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_running_job_with_http_info(job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str job_id: The id of the job. (required)
        :param str x_request_id: An unique ID for the request
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['job_id', 'x_request_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method stop_running_job" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'job_id' is set
        if self.api_client.client_side_validation and ('job_id' not in params or
                                                       params['job_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `job_id` when calling `stop_running_job`")  # noqa: E501

        if self.api_client.client_side_validation and ('x_request_id' in params and
                                                       len(params['x_request_id']) < 1):
            raise ValueError("Invalid value for parameter `x_request_id` when calling `stop_running_job`, length must be greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if 'job_id' in params:
            path_params['job_id'] = params['job_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_request_id' in params:
            header_params['X-Request-Id'] = params['x_request_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['basic']  # noqa: E501

        return self.api_client.call_api(
            '/jobservice/jobs/{job_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Harbor API

    These APIs provide services for manipulating Harbor project.  # noqa: E501

    OpenAPI spec version: 2.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from harbor_client.configuration import Configuration


class ExecHistory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'job_name': 'str',
        'job_kind': 'str',
        'job_parameters': 'str',
        'schedule': 'ScheduleObj',
        'job_status': 'str',
        'deleted': 'bool',
        'creation_time': 'datetime',
        'update_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'job_name': 'job_name',
        'job_kind': 'job_kind',
        'job_parameters': 'job_parameters',
        'schedule': 'schedule',
        'job_status': 'job_status',
        'deleted': 'deleted',
        'creation_time': 'creation_time',
        'update_time': 'update_time'
    }

    def __init__(self, id=None, job_name=None, job_kind=None, job_parameters=None, schedule=None, job_status=None, deleted=None, creation_time=None, update_time=None, _configuration=None):  # noqa: E501
        """ExecHistory - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._job_name = None
        self._job_kind = None
        self._job_parameters = None
        self._schedule = None
        self._job_status = None
        self._deleted = None
        self._creation_time = None
        self._update_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if job_name is not None:
            self.job_name = job_name
        if job_kind is not None:
            self.job_kind = job_kind
        if job_parameters is not None:
            self.job_parameters = job_parameters
        if schedule is not None:
            self.schedule = schedule
        if job_status is not None:
            self.job_status = job_status
        if deleted is not None:
            self.deleted = deleted
        if creation_time is not None:
            self.creation_time = creation_time
        if update_time is not None:
            self.update_time = update_time

    @property
    def id(self):
        """Gets the id of this ExecHistory.  # noqa: E501

        the id of purge job.  # noqa: E501

        :return: The id of this ExecHistory.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ExecHistory.

        the id of purge job.  # noqa: E501

        :param id: The id of this ExecHistory.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def job_name(self):
        """Gets the job_name of this ExecHistory.  # noqa: E501

        the job name of purge job.  # noqa: E501

        :return: The job_name of this ExecHistory.  # noqa: E501
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this ExecHistory.

        the job name of purge job.  # noqa: E501

        :param job_name: The job_name of this ExecHistory.  # noqa: E501
        :type: str
        """

        self._job_name = job_name

    @property
    def job_kind(self):
        """Gets the job_kind of this ExecHistory.  # noqa: E501

        the job kind of purge job.  # noqa: E501

        :return: The job_kind of this ExecHistory.  # noqa: E501
        :rtype: str
        """
        return self._job_kind

    @job_kind.setter
    def job_kind(self, job_kind):
        """Sets the job_kind of this ExecHistory.

        the job kind of purge job.  # noqa: E501

        :param job_kind: The job_kind of this ExecHistory.  # noqa: E501
        :type: str
        """

        self._job_kind = job_kind

    @property
    def job_parameters(self):
        """Gets the job_parameters of this ExecHistory.  # noqa: E501

        the job parameters of purge job.  # noqa: E501

        :return: The job_parameters of this ExecHistory.  # noqa: E501
        :rtype: str
        """
        return self._job_parameters

    @job_parameters.setter
    def job_parameters(self, job_parameters):
        """Sets the job_parameters of this ExecHistory.

        the job parameters of purge job.  # noqa: E501

        :param job_parameters: The job_parameters of this ExecHistory.  # noqa: E501
        :type: str
        """

        self._job_parameters = job_parameters

    @property
    def schedule(self):
        """Gets the schedule of this ExecHistory.  # noqa: E501


        :return: The schedule of this ExecHistory.  # noqa: E501
        :rtype: ScheduleObj
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this ExecHistory.


        :param schedule: The schedule of this ExecHistory.  # noqa: E501
        :type: ScheduleObj
        """

        self._schedule = schedule

    @property
    def job_status(self):
        """Gets the job_status of this ExecHistory.  # noqa: E501

        the status of purge job.  # noqa: E501

        :return: The job_status of this ExecHistory.  # noqa: E501
        :rtype: str
        """
        return self._job_status

    @job_status.setter
    def job_status(self, job_status):
        """Sets the job_status of this ExecHistory.

        the status of purge job.  # noqa: E501

        :param job_status: The job_status of this ExecHistory.  # noqa: E501
        :type: str
        """

        self._job_status = job_status

    @property
    def deleted(self):
        """Gets the deleted of this ExecHistory.  # noqa: E501

        if purge job was deleted.  # noqa: E501

        :return: The deleted of this ExecHistory.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this ExecHistory.

        if purge job was deleted.  # noqa: E501

        :param deleted: The deleted of this ExecHistory.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def creation_time(self):
        """Gets the creation_time of this ExecHistory.  # noqa: E501

        the creation time of purge job.  # noqa: E501

        :return: The creation_time of this ExecHistory.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this ExecHistory.

        the creation time of purge job.  # noqa: E501

        :param creation_time: The creation_time of this ExecHistory.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def update_time(self):
        """Gets the update_time of this ExecHistory.  # noqa: E501

        the update time of purge job.  # noqa: E501

        :return: The update_time of this ExecHistory.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this ExecHistory.

        the update time of purge job.  # noqa: E501

        :param update_time: The update_time of this ExecHistory.  # noqa: E501
        :type: datetime
        """

        self._update_time = update_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExecHistory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExecHistory):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExecHistory):
            return True

        return self.to_dict() != other.to_dict()
